@@ -37,8 +37,6 @@
 #include <QDir>
 #include <QStandardPaths>
 
-#include <QDebug>
-
 using namespace KParts;
 
 class Q_DECL_HIDDEN Plugin::PluginPrivate
@@ -91,7 +89,7 @@ QList<Plugin::PluginInfo> Plugin::pluginInfos(const QString &componentName)
 
     QMap<QString, QStringList> sortedPlugins;
 
-    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, componentName + QStringLiteral("/kpartplugins"), QStandardPaths::LocateDirectory);
+    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, componentName + QLatin1String("/kpartplugins"), QStandardPaths::LocateDirectory);
     for (const QString &dir : dirs) {
         const auto rcfiles = QDir(dir).entryList(QStringList(QStringLiteral("*.rc")));
         for (const QString &file : rcfiles) {
@@ -115,7 +113,7 @@ QList<Plugin::PluginInfo> Plugin::pluginInfos(const QString &componentName)
         }
 
         // qDebug() << "found KParts Plugin : " << info.m_absXMLFileName;
-        info.m_relXMLFileName = QStringLiteral("kpartplugins/") + mapIt.key();
+        info.m_relXMLFileName = QLatin1String("kpartplugins/") + mapIt.key();
 
         info.m_document.setContent(doc);
         if (info.m_document.documentElement().isNull()) {
@@ -135,21 +133,19 @@ void Plugin::loadPlugins(QObject *parent, const QString &componentName)
 
 void Plugin::loadPlugins(QObject *parent, const QList<PluginInfo> &pluginInfos, const QString &componentName)
 {
-    QList<PluginInfo>::ConstIterator pIt = pluginInfos.begin();
-    QList<PluginInfo>::ConstIterator pEnd = pluginInfos.end();
-    for (; pIt != pEnd; ++pIt) {
-        QString library = (*pIt).m_document.documentElement().attribute(QStringLiteral("library"));
+    for (const auto &pluginInfo : pluginInfos) {
+        const QString library = pluginInfo.m_document.documentElement().attribute(QStringLiteral("library"));
 
         if (library.isEmpty() || hasPlugin(parent, library)) {
             continue;
         }
 
-        Plugin *plugin = loadPlugin(parent, library, (*pIt).m_document.documentElement().attribute(QStringLiteral("X-KDE-PluginKeyword")));
+        Plugin *plugin = loadPlugin(parent, library, pluginInfo.m_document.documentElement().attribute(QStringLiteral("X-KDE-PluginKeyword")));
 
         if (plugin) {
             plugin->d->m_parentInstance = componentName;
-            plugin->setXMLFile((*pIt).m_relXMLFileName, false, false);
-            plugin->setDOMDocument((*pIt).m_document);
+            plugin->setXMLFile(pluginInfo.m_relXMLFileName, false, false);
+            plugin->setDOMDocument(pluginInfo.m_document);
 
         }
     }
@@ -195,14 +191,10 @@ bool Plugin::hasPlugin(QObject *parent, const QString &library)
 {
     const QObjectList plugins = parent->children();
 
-    QObjectList::ConstIterator it = plugins.begin();
-    for (; it != plugins.end(); ++it) {
-        Plugin *plugin = qobject_cast<Plugin *>(*it);
-        if (plugin && plugin->d->m_library == library) {
-            return true;
-        }
-    }
-    return false;
+    return std::any_of(plugins.begin(), plugins.end(), [&library](QObject *p) {
+        Plugin *plugin = qobject_cast<Plugin *>(p);
+        return (plugin && plugin->d->m_library == library);
+    });
 }
 
 void Plugin::setComponentData(const KAboutData &pluginData)
@@ -215,12 +207,10 @@ void Plugin::loadPlugins(QObject *parent, KXMLGUIClient *parentGUIClient,
                          const QString &componentName, bool enableNewPluginsByDefault,
                          int interfaceVersionRequired)
 {
-    KConfigGroup cfgGroup(KSharedConfig::openConfig(componentName + QStringLiteral("rc")), "KParts Plugins");
+    KConfigGroup cfgGroup(KSharedConfig::openConfig(componentName + QLatin1String("rc")), "KParts Plugins");
     const QList<PluginInfo> plugins = pluginInfos(componentName);
-    QList<PluginInfo>::ConstIterator pIt = plugins.begin();
-    const QList<PluginInfo>::ConstIterator pEnd = plugins.end();
-    for (; pIt != pEnd; ++pIt) {
-        QDomElement docElem = (*pIt).m_document.documentElement();
+    for (const auto &pluginInfo : plugins) {
+        QDomElement docElem = pluginInfo.m_document.documentElement();
         QString library = docElem.attribute(QStringLiteral("library"));
         QString keyword;
 
@@ -232,12 +222,12 @@ void Plugin::loadPlugins(QObject *parent, KXMLGUIClient *parentGUIClient,
         const QString name = docElem.attribute(QStringLiteral("name"));
 
         bool pluginEnabled = enableNewPluginsByDefault;
-        if (cfgGroup.hasKey(name + QStringLiteral("Enabled"))) {
-            pluginEnabled = cfgGroup.readEntry(name + QStringLiteral("Enabled"), false);
+        if (cfgGroup.hasKey(name + QLatin1String("Enabled"))) {
+            pluginEnabled = cfgGroup.readEntry(name + QLatin1String("Enabled"), false);
         } else { // no user-setting, load plugin default setting
-            QString relPath = componentName + QLatin1Char('/') + (*pIt).m_relXMLFileName;
+            QString relPath = componentName + QLatin1Char('/') + pluginInfo.m_relXMLFileName;
             relPath.truncate(relPath.lastIndexOf(QLatin1Char('.'))); // remove extension
-            relPath += QStringLiteral(".desktop");
+            relPath += QLatin1String(".desktop");
             //qDebug() << "looking for " << relPath;
             const QString desktopfile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, relPath);
             if (!desktopfile.isEmpty()) {
@@ -263,8 +253,8 @@ void Plugin::loadPlugins(QObject *parent, KXMLGUIClient *parentGUIClient,
         const QObjectList pluginList = parent->children();
 
         bool pluginFound = false;
-        for (QObjectList::ConstIterator it = pluginList.begin(); it != pluginList.end(); ++it) {
-            Plugin *plugin = qobject_cast<Plugin *>(*it);
+        for (auto *p : pluginList) {
+            Plugin *plugin = qobject_cast<Plugin *>(p);
             if (plugin && plugin->d->m_library == library) {
                 // delete and unload disabled plugins
                 if (!pluginEnabled) {
@@ -292,8 +282,8 @@ void Plugin::loadPlugins(QObject *parent, KXMLGUIClient *parentGUIClient,
 
         if (plugin) {
             plugin->d->m_parentInstance = componentName;
-            plugin->setXMLFile((*pIt).m_relXMLFileName, false, false);
-            plugin->setDOMDocument((*pIt).m_document);
+            plugin->setXMLFile(pluginInfo.m_relXMLFileName, false, false);
+            plugin->setDOMDocument(pluginInfo.m_document);
             parentGUIClient->insertChildClient(plugin);
         }
     }
